@@ -22,6 +22,7 @@
 -export([highlight_aim_setup/1]).
 -export([register_postdraw_hook/3,unregister_postdraw_hook/2]).
 -export([info_line/0]).
+-export([keep/1, release_all/0]).
 
 -export([new_st/0]).
 
@@ -127,9 +128,14 @@ init(File) ->
     wings_job:init(),
     wings_develop:init(),
     wings_tweak:init(),
-
+    Env = wings_io:get_process_option(),
+    Keeper = spawn_link(fun() -> 
+				wings_io:set_process_option(Env),
+				keeper([]) 
+			end),
+    register(wings_keeper, Keeper),
     Op = main_loop_noredraw(St),		%Replace crash handler
-                        %with this handler.
+						%with this handler.
     
     Props = initial_properties(),
     {{X,Y},{W,H}} = wings_wm:win_rect(desktop),
@@ -208,7 +214,17 @@ free_viewer_num(N) ->
 	true -> free_viewer_num(N+1)
     end.
 
-open_file(none) -> ok;
+open_file(none) ->
+    USFile = wings_file:autosave_filename(wings_file:unsaved_filename()),
+    Recovered = filelib:is_file(USFile),
+    wings_pref:set_value(file_recovered, Recovered),
+    case Recovered of
+        true ->
+            open_file(USFile),
+            wings_u:message(?__(1,"Wings3D has recovered an unsaved file."));
+        _ -> ok
+    end;
+
 open_file(Name) -> wings_wm:send(geom, {open_file,Name}).
 
 init_opengl(St) ->
@@ -293,9 +309,16 @@ handle_event({crash_in_other_window,LogName}, St) ->
 handle_event({open_file,Name}, St0) ->
     case catch ?SLOW(wings_ff_wings:import(Name, St0)) of
     #st{}=St1 ->
-        wings_pref:set_value(current_directory, filename:dirname(Name)),
-        St = wings_shape:recreate_folder_system(St1),
-        main_loop(wings_u:caption(St#st{saved=true,file=Name}));
+        St2 = wings_shape:recreate_folder_system(St1),
+        USFile = wings_file:autosave_filename(wings_file:unsaved_filename()),
+        St = case USFile of
+            Name ->
+                St2#st{saved=auto,file=undefined};
+            _ ->
+                wings_pref:set_value(current_directory, filename:dirname(Name)),
+                St2#st{saved=true,file=Name}
+        end,
+        main_loop(wings_u:caption(St));
     {error,_} ->
         main_loop(St0)
     end;
@@ -1623,16 +1646,9 @@ save_geom_props([], Acc) -> Acc.
 
 save_plugin_window(Name, Ns) ->
     case wings_plugin:get_win_data(Name) of
-      {M, {HAlign,CtmData}} when (HAlign=:=left) orelse (HAlign=:=right) ->
-        {MaxX,MaxY} = wings_wm:win_size(desktop),
-        {PosX0,PosY0} = case HAlign of
-            left -> wings_wm:win_ul({controller,Name});
-            right -> wings_wm:win_ur({controller,Name})
-        end,
-        PosX = if PosX0 < 0 -> 20; PosX0 > MaxX -> 20; true -> PosX0 end,
-        PosY = if PosY0 < 0 -> 20; PosY0 > MaxY -> 20; true -> PosY0 end,
-        Size = wings_wm:win_size(Name),
-        WinInfo = {M, {Name, {PosX,PosY}, Size, CtmData}},
+      {M, {_,CtmData}} ->
+        {Pos,Size} = wings_wm:win_rect(Name),
+        WinInfo = {M, {Name, Pos, Size, CtmData}},
         [WinInfo|save_windows_1(Ns)];
       _ ->
         save_windows_1(Ns)
@@ -1673,7 +1689,8 @@ restore_windows_1([{{geom,_}=Name,Pos0,Size,Ps0}|Ws], St) ->
 restore_windows_1([{Name,Pos,Size}|Ws0], St) -> % OldFormat
     restore_windows_1([{Name,Pos,Size,[]}|Ws0], St);
 restore_windows_1([{Module,{{plugin,_}=Name,{_,_}=Pos,{_,_}=Size,CtmData}}|Ws], St) ->
-	wings_plugin:restore_window(Module, Name, validate_pos(Pos), Size, CtmData, St),
+	wings_plugin:restore_window(Module, Name, Pos, Size, CtmData, St),
+    wings_wm:move(Name, Pos, Size),  % ensure the window be placed in the right position *
     restore_windows_1(Ws, St);
 restore_windows_1([{{object,_}=Name,{_,_}=Pos,{_,_}=Size,Ps}|Ws], St) ->
     wings_shape:window(Name, validate_pos(Pos), Size, Ps, St),
@@ -1720,6 +1737,9 @@ move_windows([{Name,Pos,_}|Windows]) ->
 move_windows([{Name,Pos,_,_}|Windows]) ->
     move_windows_1(Name, Pos),
     move_windows(Windows);
+move_windows([{_Module,{{plugin,_}=Name,Pos,_,_}}|Windows]) ->
+    move_windows_1(Name, Pos),
+    move_windows(Windows);
 move_windows([]) -> ok.
 
 move_windows_1(geom,Pos) ->
@@ -1728,6 +1748,8 @@ move_windows_1({geom,_}=Name,Pos) ->
     wings_wm:move(Name,Pos);
 move_windows_1({tweak, _}=Name,Pos) ->
     wings_wm:move(Name,Pos);
+move_windows_1({plugin,_}=Name,Pos) ->
+    wings_wm:move(Name,Pos);
 move_windows_1(Name,{X,Y}) ->
     case wings_wm:is_window(Name) of
       true ->
@@ -1978,3 +2000,33 @@ menu_toolbar_action({menu_toolbar,{X,_}}, St) ->
         {_,Y} = wings_wm:local2global(X0, Y0),
         popup_menu(X, Y + ?LINE_HEIGHT div 2, St)
     end.
+
+%% Garbage collection works too good sometimes and data
+%% sent to opengl can be garbage collected before it is 
+%% used in consecutiv calls.
+%% Specially now that a multithreaded emulator is used,
+%% and the calls to the driver are buffered until the 
+%% gui thread is scheduled in.
+%% To be able keep the data alive we send it to another process,
+%% instead of keeping the transient data in some datastructures.
+%% Invoke release_all after each frame is drawn so we can release the data.
+
+keep(Data) ->
+    wings_keeper ! {keep, Data},
+    ok.
+
+release_all() ->
+    wings_keeper ! release_all,
+    ok.
+
+keeper(Kept) ->
+    receive 
+	{keep, Data} ->
+	    keeper([Data|Kept]);
+	release_all ->
+	    %% Do a sync call to gui thread when it returns
+	    %% we know all previous calls have been done
+	    [_|_] = gl:getIntegerv(?GL_RED_BITS),
+	    keeper([])
+    end.
+	    
