@@ -45,14 +45,14 @@ render(#st{selmode=Mode}=St) ->
 	undefined -> ok
     end,
     SceneLights = wings_view:load_matrices(true),
-    ground_and_axes(),
+    Yon = ground_and_axes(),
     mini_axis_icon(),
     show_saved_bb(St),
     show_bb_center(St),
     user_clipping_planes(on),
     render_objects(Mode, SceneLights),
     user_clipping_planes(off),
-    axis_letters(),
+    axis_letters(Yon),
     gl:lineWidth(1),
     wings_io:ortho_setup(),
     gl:polygonMode(?GL_FRONT_AND_BACK, ?GL_LINE),
@@ -371,7 +371,7 @@ draw_vertices(#dlo{src_we=#we{perm=P},vs=VsDlist}, vertex) when ?IS_SELECTABLE(P
     wings_dl:call(VsDlist);
 draw_vertices(_, _) -> ok.
 
-draw_hilite(#dlo{hilite=DL}) ->
+draw_hilite(#dlo{hilite=DL}) -> 
     wings_dl:call(DL).
 
 draw_orig_sel(#dlo{orig_sel=none}) -> ok;
@@ -408,7 +408,7 @@ draw_hard_edges(#dlo{hard=Hard}, SelMode) ->
     gl:lineWidth(hard_edge_width(SelMode)),
     gl:color3fv(wings_pref:get_value(hard_edge_color)),
     wings_dl:call(Hard).
-
+	
 draw_normals(#dlo{normals=none}) -> ok;
 draw_normals(#dlo{normals=Ns}) ->
     gl:color3f(0, 0, 1),
@@ -426,20 +426,19 @@ draw_plugins(Flag,D,Selmode) ->
 
 ground_and_axes() ->
     Axes = wings_wm:get_prop(show_axes),
-    groundplane(Axes),
-    case wings_pref:get_value(constrain_axes) of
-	true ->
-		GridAmount=wings_pref:get_value(ground_grid_amount),
-		Yon = ?GROUND_GRID_SIZE * float(GridAmount);
-	false -> #view{yon=Yon} = wings_view:current()
-    end,
+    GridSize = groundplane(Axes),
+    Yon = case wings_pref:get_value(constrain_axes) of
+	      true  -> GridSize;
+	      false -> (wings_view:current())#view.yon
+	  end,
     case Axes of
 	true ->
 	    axis(1, Yon, get_pref(x_color), get_pref(neg_x_color)),
 	    axis(2, Yon, get_pref(y_color), get_pref(neg_y_color)),
 	    axis(3, Yon, get_pref(z_color), get_pref(neg_z_color));
 	false -> ok
-    end.
+    end,
+    Yon.
 
 get_pref(Key) ->
     wings_pref:get_value(Key).
@@ -463,7 +462,7 @@ dummy_axis_letter() ->
     PM = list_to_tuple(gl:getDoublev(?GL_PROJECTION_MATRIX)),
     %% Since this is a workaround, we will do a real fetching
     %% of the viewport (rather than wings_wm:viewport/0).
-    [X,Y,W,H] = gl:getIntegerv(?GL_VIEWPORT),
+    [X,Y,W,H|_] = gl:getIntegerv(?GL_VIEWPORT),
     Viewport = {X,Y,W,H},
     dummy_axis_letter(MM, PM, Viewport).
 
@@ -482,7 +481,7 @@ dummy_axis_letter(_, _, {_,_,W,H}) ->
     gl:popMatrix(),
     gl:matrixMode(?GL_MODELVIEW).
 
-axis_letters() ->
+axis_letters(Yon0) ->
     case wings_wm:get_prop(show_axes) of
 	false ->
 	    case wings_pref:get_value(dummy_axis_letter) of
@@ -503,13 +502,7 @@ axis_letters() ->
 	    glu:ortho2D(0, W, 0, H),
 	    gl:matrixMode(?GL_MODELVIEW),
 	    gl:loadIdentity(),
-
-	    case wings_pref:get_value(constrain_axes) of
-		true ->
-			GridAmount=wings_pref:get_value(ground_grid_amount),
-			Yon = ?GROUND_GRID_SIZE * (float(GridAmount) +1.0);
-		false -> #view{yon=Yon} = wings_view:current()
-	    end,
+	    Yon = Yon0 + ?GROUND_GRID_SIZE,
 	    axis_letter_1(1, Yon, axisx, x_color, Info),
 	    axis_letter_1(2, Yon, axisy, y_color, Info),
 	    axis_letter_1(3, Yon, axisz, z_color, Info)
@@ -579,15 +572,23 @@ sub({X1,Y1}, {X2,Y2}) ->
 add_prod({X1,Y1}, {X2,Y2}, S) when is_float(S) ->
     {S*X2+X1,S*Y2+Y1}.
 
+calc_grid_size() ->
+    {MM,PM,{_,_,W0,H0}=Viewport} = wings_u:get_matrices(0, original),
+    W1=max(W0,H0)/2.0,
+    {S,T,U} = wings_gl:unProject(W1, 0.0, 0.0, MM, PM, Viewport),
+    ?GROUND_GRID_SIZE*max(round(max(max(abs(S),abs(T)),abs(U))),10.0).
+
 groundplane(Axes) ->
+    GridSize = calc_grid_size(),
     case (wings_wm:get_prop(show_groundplane) orelse
 	  (wings_pref:get_value(force_show_along_grid) andalso
 	   (wings_view:current())#view.along_axis =/= none)) of
-	true -> groundplane_1(Axes);
+	true -> groundplane_1(Axes, GridSize);
 	false -> ok
-    end.
+    end,
+    float(GridSize).
 
-groundplane_1(Axes) ->
+groundplane_1(Axes, Sz) ->
     #view{along_axis=Along} = wings_view:current(),
     gl:color3fv(wings_pref:get_value(grid_color)),
     gl:lineWidth(1),
@@ -599,8 +600,6 @@ groundplane_1(Axes) ->
 	_ -> gl:rotatef(90, 1, 0, 0)
     end,
     gl:'begin'(?GL_LINES),
-	GridAmount=wings_pref:get_value(ground_grid_amount),
-    Sz = ?GROUND_GRID_SIZE * GridAmount,
     groundplane_2(-Sz, Sz, Sz, Axes),
     gl:'end'(),
     gl:popMatrix(),
@@ -686,7 +685,7 @@ enable_lighting(SceneLights) ->
 	    %% We put it here and not in apply_material, because we
 	    %% can't use some optimizations (e.g. reuse display lists)
 	    %% when drawing selected objects.
-	    gl:color4ub(255, 255, 255, 255),
+	    gl:color4ub(255, 255, 255, 255), 
 	    gl:useProgram(Prog)
     end.
 
@@ -698,7 +697,7 @@ disable_lighting() ->
     end.
 
 mini_axis_icon() ->
-    case wings_pref:get_value(mini_axis) of
+    case wings_pref:get_value(mini_axis) of 
     false -> ok;
     true ->
       gl:pushAttrib(?GL_ALL_ATTRIB_BITS),
