@@ -301,7 +301,7 @@ command(orthogonal_view, St) ->
     St;
 command({show,What}, St) ->
     Prev = toggle_option(What),
-    if
+    if 
 	What =:= show_normals ->
 	    Prev andalso wings_dl:map(fun(D, _) -> D#dlo{normals=none} end, []);
 	What =:= show_materials; What =:= filter_texture ->
@@ -885,18 +885,16 @@ reset() ->
     reset(current()).
 
 reset(View) ->
-    Distance=wings_pref:get_value(ground_grid_amount)*0.5, %  80% of the grid size
     set_current(View#view{origin={0.0,0.0,0.0},
 			  azimuth=-45.0,elevation=25.0,
-			  distance=max(Distance,8.0),
+			  distance=?CAMERA_DIST,
 			  pan_x=0.0,pan_y=0.0,
 			  along_axis=none}).
 
 default_view() ->
-    Distance=wings_pref:get_value(ground_grid_amount)*0.5, %  80% of the grid size
     #view{origin={0.0,0.0,0.0},
 	  azimuth=-45.0,elevation=25.0,
-	  distance=max(Distance,8.0),
+	  distance=?CAMERA_DIST,
 	  pan_x=0.0,pan_y=0.0,
 	  along_axis=none,
 	  fov=45.0,
@@ -1056,7 +1054,7 @@ frame(St0) ->
     St = case wings_pref:get_value(frame_disregards_mirror) of
 	true ->
       kill_mirror(St0);
-	false ->
+	false -> 
 	  St0
 	end,
     frame_1(wings_sel:bounding_box(St)).
@@ -1388,15 +1386,20 @@ one_of(false,_, S) -> S.
 
 export_views(#st{views={_,Views0}}) ->
     Views1 = tuple_to_list(Views0),
-    CurrentView = current(),
-    Views = case get_view_index(CurrentView,Views1) of
-        undefined ->
-            [{CurrentView,"current_view"}]++Views1;
-        Idx ->
-            View = element(Idx,Views0),
-            Views2 = Views1 -- [View],  % tuple index starts from 1 and lists from 0
-            [View]++Views2
-    end,
+    Views = case get(wings_not_running) of
+		undefined ->
+		    CurrentView = current(),
+		    case get_view_index(CurrentView,Views1) of
+			undefined ->
+			    [{CurrentView,"current_view"}]++Views1;
+			Idx ->
+			    View = element(Idx,Views0),
+			    Views2 = Views1 -- [View],  % tuple index starts from 1 and lists from 0
+			    [View]++Views2
+		    end;
+		_ ->
+		    Views1
+	    end,
     export_views_1(Views).
 
 export_views_1([{View,Name}|Views]) ->
@@ -1408,23 +1411,24 @@ export_views_1([]) -> [].
 import_views(Views, #st{views={CurrentView0,{}}}=St) -> % loading a project
     NewViews0 = import_views_1(Views),
     NewViews = case NewViews0 of
-        [] ->
-            reset(),
-            CurrentView = CurrentView0,
-            NewViews0;
-        _ ->
-            {{View,_},NewViews1} = remove_cur_view(NewViews0),
-            set_current(View),
-            CurrentView = case get_view_index(View,NewViews1) of
-                undefined -> CurrentView0;
-                Idx -> Idx
-            end,
-            NewViews1
-    end,
+		   [] ->
+		       reset(),
+		       CurrentView = CurrentView0,
+		       NewViews0;
+		   _ ->
+		       {{View,_},NewViews1} = remove_cur_view(NewViews0),
+		       (get(wings_not_running) == undefined) andalso set_current(View),
+		       CurrentView = case get_view_index(View,NewViews1) of
+					 undefined -> CurrentView0;
+					 Idx -> Idx
+				     end,
+		       NewViews1
+	       end,
     St#st{views={CurrentView,list_to_tuple(NewViews)}};
 import_views(Views, #st{views={CurrentView,OldViews}}=St) -> % merging a project
     NewViews0 = import_views_1(Views),
-    NewViews = tuple_to_list(OldViews)++remove_cur_view(NewViews0),
+    {{_,_},NewViews1} = remove_cur_view(NewViews0),
+    NewViews = tuple_to_list(OldViews)++NewViews1,
     St#st{views={CurrentView,list_to_tuple(NewViews)}}.
 
 import_views_1([{view,As}|Views]) ->
